export

Function export 

pub fn export<W, P>(provider: &P, config: &ExportConfig) -> Result<Vec<PathBuf>>
where W: EraBlockWriter, P: BlockReader, P::Header: BlockHeader + Sealable + Encodable, <<P as BlockReader>::Block as Block>::Body: Encodable, P::Receipt: Receipt,
Fetches block history from provider and writes it to ERA files in the W format, chunked by ExportConfig::max_blocks_per_file.

Returns the paths of the files that were created.